==> openmsghard-1.0.1.tar.gz: openmsghard-1.0.1/list_file.c <==
#include "list_file.h"
#include "common.h"
#define MAX_PATH 2048
list_file* get_list_file( char *dirname ,int *max_count) { 
	printf("start get_list_file()1\n");	
	DIR *dir_ptr; /* the directory */ 
	struct dirent *direntp; /* each entry */
        printf("dirpath %s\n",dirname);
	//strncpy(pub_present_path,dirname,strlen(dirname));
	list_file *p=NULL;
	list_file *head=NULL;
	
        //printf("start get_list_file()3\n");
	//printf("before head %p\n",head);
	head=(list_file*)malloc(sizeof(list_file));	
	//printf("after head %p\n",head);
	//printf("::: Malloc :::\n");
        //printf("start get_list_file()4\n");
	pub_head=NULL;
	pub_head = head;
	head->Next=NULL;
	//printf("list_file() check\n");	
		
	if ( ( dir_ptr = opendir( dirname ) ) == NULL ) {
		fprintf(stderr,"ls1: cannot open %s\n", dirname);
	} 
	else {
		//printf("else\n"); 
		while ( ( direntp = readdir( dir_ptr ) ) != NULL ) {
			//printf("dostat\n");
			dostat(dirname, direntp->d_name ,head); 
			
			}
	}
	p=head;
	int i=0;
	//printf("list_file() while before\n");
	while(p=p->Next) {
		p->data.count=++i;
			//printf(" ====%d\n",p->data.count);	
		//printf("list.c %d %s\r\t\t\t\t\t\t\t %6.1f %s  %s\n",p->data.isdir,p->data.initial,p->data.size,p->data.unit,p->data.date);
	//printf("   %s\n",p->data.date);
	}

	printf("after while\n");	
	*max_count=i;
	closedir(dir_ptr); 
	return head;
} 

void dostat(char *dirname, char *filename ,list_file *head) { 
	//printf("start dostat()\n");

	struct stat info; 
	
	list_file *node=(list_file *)malloc(sizeof(list_file));
	char path[strlen(dirname)+strlen(filename)+2];
	memset(path,0x0,sizeof(path));	
	snprintf(path,(strlen(dirname)+strlen(filename))+2,"%s/%s",dirname,filename);

		


	if ( stat(path, &info) == -1 ) {	
		perror( filename ); /* say why */ 
	}
	else {  
		if(strcmp(filename,".")==0 || strcmp(filename,"..")==0) {
			;
		}
		else {	

			show_file_info(path, &info ,head,filename); 
		}
		
	}
} 

void show_file_info( char *path, struct stat *info_p,list_file *head,char *filename ) { 
	//printf("Start show_file_info()\n"); 
	struct tm *tm_ptr;
	char buffer[9];
	list_file *t;
	tm_ptr=localtime(&info_p->st_ctime);

	strftime(buffer,9, "%y/%m/%d", tm_ptr);
	list_file* node=(list_file*)malloc(sizeof(list_file));
	//printf("::: Malloc() ::: %d\n",sizeof(list_file));

        node->Next=NULL;
	node->data.ori_date=info_p->st_ctime;
	node->data.ori_size = 0;
        if ( S_ISDIR(info_p->st_mode) ) node->data.isdir=1;
	else node->data.isdir=0;
	memset(node->data.filename,0x0,256);
        strncpy(node->data.filename,filename,strlen(filename));
	//printf(" %s ,f %d,p %d\n",node->data.filename,strlen(filename),strlen(node->data.filename));
	memset(node->data.date,0x0,9);
        strncpy(node->data.date,buffer,9);
	node->data.date[strlen(node->data.date)] = '\0';
	strncpy(node->data.initial,filename,50-3);
	node->data.initial[41]='.';
	node->data.initial[42]='.';
	node->data.initial[43]='\0';

	if(S_ISDIR(info_p->st_mode)) {
		node->data.size=0;
		strncpy(node->data.unit,"  ",2);	

	}
	else {	
	if(((long)info_p->st_size) > 1000000) {
		strncpy(node->data.unit,"MB",2);
		node->data.size=(float)((long)info_p->st_size) / 1000000;
		node->data.unit[2]='\0';	
	        node->data.ori_size = (long)info_p->st_size;

	}
	else {
		node->data.size=(float)((long)info_p->st_size) / 1000;
		strncpy(node->data.unit,"KB",2);
		node->data.unit[2]='\0';
	        node->data.ori_size = (long)info_p->st_size;

	}
	}
	//printf("%s\n",node->data.date);
       
	list_file *p;
	p=head;

        if(p==NULL) {
                head->Next=node;
        }
        else {
                while(p->Next!=NULL) {

                        t=p->Next;

                        if(t->data.ori_date < node->data.ori_date) {

                                t=p->Next;
                                p->Next=node;
                                node->Next=t;
                                break;
                        }
                        p=p->Next;


                }
                p->Next=node;
        }



}
void delete_all(list_file *head,int max_count) {
        list_file *p=NULL;
        list_file *t=NULL;


        p=head;

while(p=p->Next) {

//printf("list check\n");
}
p=head;
p=p->Next;	
        while((p)!=NULL && max_count!=0) {
		//printf("p = %p\n",p);
                t=p->Next;
                free(p);
		
		p=t;
                //printf("::: free()\n");
        }
        //
printf("head free()\n");
	//head->Next=NULL;
	t=p=NULL;
        free(head);
/*

        p=head;

        while((p->Next)!=NULL && max_count !=0) {
                t=p->Next;

                free(p);
                p=t;
                printf("free()\n");

        }

        printf("head free()\n");
        t=p=NULL;
        free(head);
*/

}



void pub_delete_all(pub_list *publist_head,int max_count) {

        pub_list *p=NULL;
        pub_list *t=NULL;

        p=publist_head;
	p=p->Next;
        while((p)!=NULL && max_count!=0) {
                t=p->Next;
                free(p);

                p=t;
                //printf(":::publist free()\n");
        }
        printf("publist_head free()\n");
        publist_head->Next=NULL;
        t=p=NULL;
        free(publist_head);

/*
        while((p->Next)!=NULL && max_count !=0) {
                t=p->Next;

                free(p);
                p=t;
                printf("free()\n");
		
        }

        printf("publist_head free()\n");
	t=p=NULL;
        free(publist_head);

*/
}

void mv_present(char *present_path) {
	//printf("start mv_present()\n");
	char tmp_path[MAX_PATH];
	char *path_tok[256];

	//printf("before memset\n");
	memset(path_tok,0x0,sizeof(path_tok));
	memset(tmp_path,0x0,MAX_PATH);
	//printf("before strncpy()\n");
	strncpy(tmp_path,present_path,strlen(present_path));
	memset(present_path,0x0,MAX_PATH);
	//printf("tmp_path : %s\n",tmp_path);
	msn_strtok_path(tmp_path,path_tok);
	//printf("tmp_path2 : %s\n",tmp_path);
	int i=0;
	memset(present_path,0x0,MAX_PATH);
	//printf("before while\n");
	while(path_tok[i+1]) {
		//printf("%s\n",path_tok[i]);
		strcat(present_path,"/");
		strcat(present_path,path_tok[i]);
		i++;

	}
	//printf("end while %s\n",present_path);
	strncpy(present_path,tmp_path,strlen(tmp_path));
}

==> openmsghard-1.0.3.tar.gz: openmsghard-1.0.3/list_file.c <==
#include "list_file.h"
#include "common.h"
#define MAX_PATH 2048
list_file* get_list_file( char *dirname ,int *max_count) { 
	printf("start get_list_file()1\n");	
	DIR *dir_ptr; /* the directory */ 
	struct dirent *direntp; /* each entry */
        printf("dirpath %s\n",dirname);
	//strncpy(pub_present_path,dirname,strlen(dirname));
	list_file *p=NULL;
	list_file *head=NULL;
	
        //printf("start get_list_file()3\n");
	//printf("before head %p\n",head);
	head=(list_file*)malloc(sizeof(list_file));	
	//printf("after head %p\n",head);
	//printf("::: Malloc :::\n");
        //printf("start get_list_file()4\n");
	pub_head=NULL;
	pub_head = head;
	head->Next=NULL;
	//printf("list_file() check\n");	
		
	if ( ( dir_ptr = opendir( dirname ) ) == NULL ) {
		fprintf(stderr,"ls1: cannot open %s\n", dirname);
	} 
	else {
		//printf("else\n"); 
		while ( ( direntp = readdir( dir_ptr ) ) != NULL ) {
			//printf("dostat\n");
			dostat(dirname, direntp->d_name ,head); 
			
			}
	}
	p=head;
	int i=0;
	//printf("list_file() while before\n");
	while(p=p->Next) {
		p->data.count=++i;
			//printf(" ====%d\n",p->data.count);	
		//printf("list.c %d %s\r\t\t\t\t\t\t\t %6.1f %s  %s\n",p->data.isdir,p->data.initial,p->data.size,p->data.unit,p->data.date);
	//printf("   %s\n",p->data.date);
	}

	printf("after while\n");	
	*max_count=i;
	closedir(dir_ptr); 
	return head;
} 

void dostat(char *dirname, char *filename ,list_file *head) { 
	//printf("start dostat()\n");

	struct stat info; 
	
//	list_file *node=(list_file *)malloc(sizeof(list_file));
	char path[strlen(dirname)+strlen(filename)+2];
	memset(path,0x0,sizeof(path));	
	snprintf(path,(strlen(dirname)+strlen(filename))+2,"%s/%s",dirname,filename);

		


	if ( stat(path, &info) == -1 ) {	
		perror( filename ); /* say why */ 
	}
	else {  
		if(strcmp(filename,".")==0 || strcmp(filename,"..")==0) {
			;
		}
		else {	

			show_file_info(path, &info ,head,filename); 
		}
		
	}
} 

void show_file_info( char *path, struct stat *info_p,list_file *head,char *filename ) { 
	//printf("Start show_file_info()\n"); 
	struct tm *tm_ptr;
	char buffer[9];
	list_file *t;
	tm_ptr=localtime(&info_p->st_ctime);

	strftime(buffer,9, "%y/%m/%d", tm_ptr);
	list_file* node=(list_file*)malloc(sizeof(list_file));
	//printf("::: Malloc() ::: %d\n",sizeof(list_file));

        node->Next=NULL;
	node->data.ori_date=info_p->st_ctime;
	node->data.ori_size = 0;
        if ( S_ISDIR(info_p->st_mode) ) node->data.isdir=1;
	else node->data.isdir=0;
	memset(node->data.filename,0x0,256);
        strncpy(node->data.filename,filename,strlen(filename));
	//printf(" %s ,f %d,p %d\n",node->data.filename,strlen(filename),strlen(node->data.filename));
	memset(node->data.date,0x0,9);
        strncpy(node->data.date,buffer,9);
	node->data.date[strlen(node->data.date)] = '\0';
	strncpy(node->data.initial,filename,50-3);
	node->data.initial[41]='.';
	node->data.initial[42]='.';
	node->data.initial[43]='\0';

	if(S_ISDIR(info_p->st_mode)) {
		node->data.size=0;
		strncpy(node->data.unit,"  ",2);	

	}
	else {	
	if(((long)info_p->st_size) > 1000000) {
		strncpy(node->data.unit,"MB",2);
		node->data.size=(float)((long)info_p->st_size) / 1000000;
		node->data.unit[2]='\0';	
	        node->data.ori_size = (long)info_p->st_size;

	}
	else {
		node->data.size=(float)((long)info_p->st_size) / 1000;
		strncpy(node->data.unit,"KB",2);
		node->data.unit[2]='\0';
	        node->data.ori_size = (long)info_p->st_size;

	}
	}
	//printf("%s\n",node->data.date);
       
	list_file *p;
	p=head;

        if(p==NULL) {
                head->Next=node;
        }
        else {
                while(p->Next!=NULL) {

                        t=p->Next;

                        if(t->data.ori_date < node->data.ori_date) {

                                t=p->Next;
                                p->Next=node;
                                node->Next=t;
                                break;
                        }
                        p=p->Next;


                }
                p->Next=node;
        }



}
void delete_all(list_file *head,int max_count) {
        list_file *p=NULL;
        list_file *t=NULL;


        p=head;

while(p=p->Next) {

//printf("list check\n");
}
p=head;
p=p->Next;	
        while((p)!=NULL && max_count!=0) {
		//printf("p = %p\n",p);
                t=p->Next;
                free(p);
		
		p=t;
                //printf("::: free()\n");
        }
        //
printf("head free()\n");
	//head->Next=NULL;
	t=p=NULL;
        free(head);
/*

        p=head;

        while((p->Next)!=NULL && max_count !=0) {
                t=p->Next;

                free(p);
                p=t;
                printf("free()\n");

        }

        printf("head free()\n");
        t=p=NULL;
        free(head);
*/

}



void pub_delete_all(pub_list *publist_head,int max_count) {

        pub_list *p=NULL;
        pub_list *t=NULL;

        p=publist_head;
	p=p->Next;
        while((p)!=NULL && max_count!=0) {
                t=p->Next;
                free(p);

                p=t;
                //printf(":::publist free()\n");
        }
        printf("publist_head free()\n");
        publist_head->Next=NULL;
        t=p=NULL;
        free(publist_head);

/*
        while((p->Next)!=NULL && max_count !=0) {
                t=p->Next;

                free(p);
                p=t;
                printf("free()\n");
		
        }

        printf("publist_head free()\n");
	t=p=NULL;
        free(publist_head);

*/
}

void club_delete_all(club_list *clublist_head,int max_count) {

        club_list *p=NULL;
        club_list *t=NULL;

        p=clublist_head;
        p=p->Next;
        while((p)!=NULL && max_count!=0) {
                t=p->Next;
                free(p);

                p=t;
                //printf(":::publist free()\n");
        }
        printf("clublist_head free()\n");
        clublist_head->Next=NULL;
        t=p=NULL;
        free(clublist_head);

/*
        while((p->Next)!=NULL && max_count !=0) {
                t=p->Next;

                free(p);
                p=t;
                printf("free()\n");

        }

        printf("publist_head free()\n");
        t=p=NULL;
        free(publist_head);

*/
}

void mv_present(char *present_path) {
	//printf("start mv_present()\n");
	char tmp_path[MAX_PATH];
	char *path_tok[256];

	//printf("before memset\n");
	memset(path_tok,0x0,sizeof(path_tok));
	memset(tmp_path,0x0,MAX_PATH);
	//printf("before strncpy()\n");
	strncpy(tmp_path,present_path,strlen(present_path));
	memset(present_path,0x0,MAX_PATH);
	//printf("tmp_path : %s\n",tmp_path);
	msn_strtok_path(tmp_path,path_tok);
	//printf("tmp_path2 : %s\n",tmp_path);
	int i=0;
	memset(present_path,0x0,MAX_PATH);
	//printf("before while\n");
	while(path_tok[i+1]) {
		//printf("%s\n",path_tok[i]);
		strcat(present_path,"/");
		strcat(present_path,path_tok[i]);
		i++;

	}
	//printf("end while %s\n",present_path);
	strncpy(present_path,tmp_path,strlen(tmp_path));
}
